Inversion

Struct Inversion 

pub struct Inversion {
    pub atom_ids: (usize, usize, usize, usize),
}
Inversion entry emitted in the final topology.

Fields

atom_ids: (usize, usize, usize, usize)

The IDs of the four atoms (center, axis, plane1, plane2) where center is the inversion center, axis is the unique neighbor defining the axis, with plane1 and plane2 sorted.

Implementations

Source

impl Inversion

pub fn new(center: usize, axis: usize, plane1: usize, plane2: usize) -> Self

Creates a new inversion with plane atoms sorted to a canonical order.